Skip to main contentModule call
Source - _sysctl⚠
- Read/write system parameters.
- accept⚠
- Accept a connection on a socket.
- accept4⚠
- Accept a connection on a socket.
- access⚠
- Check user’s permission for a file.
- acct⚠
- Switch process accounting.
- add_key⚠
- Add a key to the kernel’s key management facility.
- adjtimex⚠
- Tune kernel clock. Returns clock state on success.
- alarm⚠
- Set an alarm clock for delivery of a signal.
- arch_prctl⚠
- Set architecture-specific thread state.
- bind⚠
- Bind a name to a socket.
- bpf⚠
- Perform a command on an extended BPF map or program
- brk⚠
- Change data segment size.
- cachestat⚠
cachestat() returns the page cache statistics of a file in the
bytes range specified by off and len.- capget⚠
- Get capabilities of thread.
- capset⚠
- Set capabilities of thread.
- chdir⚠
- Change working directory.
- chmod⚠
- Change permissions of a file.
- chown⚠
- Change ownership of a file.
- chroot⚠
- Change the root directory.
- clock_adjtime⚠
- Tune kernel clock.
- clock_getres⚠
- Get resolution(precision) of the specific clock.
- clock_gettime⚠
- Get time of specific clock.
- clock_nanosleep⚠
- High resolution sleep with a specific clock.
- clock_settime⚠
- Set time of specific clock.
- clone⚠
- Create a child process.
- clone3⚠
- New api to create child process.
- close⚠
- Close a file descriptor.
- close_range⚠
- Close all file descriptors in a given range
- connect⚠
- Initialize a connection on a socket.
- copy_file_range⚠
- Copy a range of data from one file to another.
- creat⚠
- Create a file.
- delete_module⚠
- Unlock a kernel module.
- dup⚠
- Create a copy of the file descriptor
oldfd, using the lowest available
file descriptor. - dup2⚠
- Create a copy of the file descriptor
oldfd, using the speficified file
descriptor newfd. - dup3⚠
- Save as
dup2(), but can set the close-on-exec flag on newfd. - epoll_create⚠
- Open an epoll file descriptor.
- epoll_create1⚠
- Open an epoll file descriptor.
- epoll_ctl⚠
- Control interface for an epoll file descriptor.
- epoll_pwait⚠
- Wait for an I/O event on an epoll file descriptor.
- epoll_pwait2⚠
- Wait for an I/O event on an epoll file descriptor.
- epoll_wait⚠
- Wait for an I/O event on an epoll file descriptor.
- eventfd⚠
- Create a file descriptor for event notification.
- eventfd2⚠
- Create a file descriptor for event notification.
- execve⚠
- Execute a new program.
- execveat⚠
- Execute a new program relative to a directory file descriptor.
- exit⚠
- Terminate current process.
- exit_group⚠
- Exit all threads in a process’s thread group.
- faccessat⚠
- Check user’s permission for a file.
- faccessat2⚠
- Check user’s permission for a file.
- fadvise64⚠
- Predeclare an access pattern for file data.
- fallocate⚠
- Manipulate file space.
- fanotify_init⚠
- Create and initialize fanotify group.
- fanotify_mark⚠
- Add, remove, or modify an fanotify mark on a filesystem object
- fchdir⚠
- Change working directory.
- fchmod⚠
- Change permissions of a file.
- fchmodat⚠
- Change permissions of a file.
- fchmodat2⚠
- Change permissions of a file.
- fchown⚠
- Change ownership of a file.
- fchownat⚠
- Change ownership of a file.
- fcntl⚠
- manipulate file descriptor.
- fdatasync⚠
- Flush all modified in-core data (exclude metadata) refered by
fd to disk. - fgetxattr⚠
- Get extended attribute value.
- finit_module⚠
- Load a kernel module.
- flistxattr⚠
- List extended attribute names.
- flock⚠
- Apply or remove an advisory lock on an open file.
- fork⚠
- Create a child process.
- fremovexattr⚠
- Remove an extended attribute.
- fsconfig⚠
- Set parameters and trigger actions on a context.
- fsetxattr⚠
- Set extended attribute value.
- fsmount⚠
- Create a kernel mount representation for a new, prepared superblock.
- fsopen⚠
- Open a filesystem by name so that it can be configured for mounting.
- fspick⚠
- Pick a superblock into a context for reconfiguration.
- fstat⚠
- Get file status about a file descriptor.
- fstatfs⚠
- Get filesystem statistics.
- fsync⚠
- Flush all modified in-core data refered by
fd to disk. - ftruncate⚠
- Truncate an opened file to a specified length.
- futex⚠
- Fast user-space locking.
- futex_requeue⚠
- Requeue a waiter from one futex to another.
- futex_wait⚠
- Wait on a futex.
- futex_waitv⚠
- Wait on a list of futexes.
- futex_wake⚠
- Wake a number of futexes.
- futimesat⚠
- Change timestamp of a file relative to a directory file discriptor.
- get_mempolicy⚠
- Retrieve NUMA memory policy for a thread
- get_robust_list⚠
- Get the robust-futex list head of a task.
- get_thread_area⚠
- Get thread-local storage information.
- getcpu⚠
- Determine CPU and NUMA node on which the calling thread is running.
- getcwd⚠
- Get current working directory.
- getdents⚠
- Get directory entries.
- getdents64⚠
- Get directory entries.
- getegid⚠
- Get the effective group ID of the calling process.
- geteuid⚠
- Get the effective user ID of the calling process.
- getgid⚠
- Get the real group ID of the calling process.
- getgroups⚠
- Get list of supplementary group Ids.
- getitimer⚠
- Get value of an interval timer.
- getpeername⚠
- Get name of connected peer socket.
- getpgid⚠
- Returns the PGID(process group ID) of the process specified by
pid. - getpgrp⚠
- Get the process group ID of the calling process.
- getpid⚠
- Get the process ID (PID) of the calling process.
- getppid⚠
- Get the process ID of the parent of the calling process.
- getpriority⚠
- Get program scheduling priority.
- getrandom⚠
- Obtain a series of random bytes.
- getresgid⚠
- Get real, effect and saved group ID.
- getresuid⚠
- Get real, effect and saved user ID.
- getrlimit⚠
- Get resource limit.
- getrusage⚠
- Get resource usage.
- getsid⚠
- Get session Id.
- getsockname⚠
- Get current address to which the socket
sockfd is bound. - getsockopt⚠
- Get options on sockets
- gettid⚠
- Get the caller’s thread ID (TID).
- gettimeofday⚠
- Get time.
- getuid⚠
- Get the real user ID of the calling process.
- getxattr⚠
- Get extended attribute value.
- init_module⚠
- Load a kernel module.
- inotify_add_watch⚠
- Add a watch to an initialized inotify instance.
- inotify_init⚠
- Initialize an inotify instance.
- inotify_init1⚠
- Initialize an inotify instance.
- inotify_rm_watch⚠
- Remove an existing watch from an inotify instance.
- io_cancel⚠
- Attempts to cancel an iocb previously passed to
io_submit. - io_destroy⚠
- Destroy the
aio_context specified. - io_getevents⚠
- Attempts to read at least
min_nr events and up to nr events from
the completion queue for the aio_context specified by ctx_id. - io_pgetevents⚠
- Read asynchronous I/O events from the completion queue
- io_setup⚠
- Create an asynchronous I/O context.
- io_submit⚠
- Queue the nr iocbs pointed to by
iocb for processing. - io_uring_enter⚠
- Initiate and/or complete asynchronous I/O
- io_uring_register⚠
- Register files or user buffers for asynchronous I/O
- io_uring_setup⚠
- Setup a context for performing asynchronous I/O.
- ioctl⚠
- Control device.
- ioperm⚠
- Set port input/output permissions.
- iopl⚠
- Change I/O privilege level.
- ioprio_get⚠
- Get I/O scheduling class and priority.
- ioprio_set⚠
- Set I/O scheduling class and priority.
- kcmp⚠
- Compare two processes to determine if they share a kernel resource.
- kexec_file_load⚠
- Load a new kernel for later execution.
- kexec_load⚠
- Load a new kernel for later execution.
- keyctl⚠
- Manipulate the kernel’s key management facility.
- kill⚠
- Send signal to a process.
- lchown⚠
- Change ownership of a file. Does not deference symbolic link.
- lgetxattr⚠
- Get extended attribute value.
- link⚠
- Make a new name for a file.
- linkat⚠
- Make a new name for a file.
- listen⚠
- Listen for connections on a socket.
- listmount⚠
- listxattr⚠
- List extended attribute names.
- llistxattr⚠
- List extended attribute names.
- lookup_dcookie⚠
- Return a directory entry’s path.
- lremovexattr⚠
- Remove an extended attribute.
- lseek⚠
- Reposition file offset.
- lsetxattr⚠
- Set extended attribute value.
- lstat⚠
- Get file status about a file, without following symbolic.
- madvise⚠
- Give advice about use of memory.
- map_shadow_stack⚠
- mbind⚠
- Set memory policy for a memory range.
- membarrier⚠
- Issue memory barriers on a set of threads.
- memfd_create⚠
- Create an anonymous file.
- memfd_secret⚠
- create an anonymous RAM-based file to access secret memory regions.
- migrate_pages⚠
- Move all pages in a process to another set of nodes
- mincore⚠
mincore() returns the memory residency status of the pages in the
current process’s address space specified by [addr, addr + len).- mkdir⚠
- Create a directory.
- mkdirat⚠
- Create a directory.
- mknod⚠
- Create a special or ordinary file.
- mknodat⚠
- Create a special or ordinary file.
- mlock⚠
- Lock memory.
- mlock2⚠
- Lock memory.
- mlockall⚠
- Lock memory.
- mmap⚠
- Map files or devices into memory.
- mount⚠
- Mount filesystem.
- move_mount⚠
- Move a mount from one place to another.
- move_pages⚠
- Move individual pages of a process to another node
- mprotect⚠
- Set protection on a region of memory.
- mq_getsetattr⚠
- Get/set message queue attributes
- mq_notify⚠
- Register for notification when a message is available
- mq_open⚠
- Open a POSIX message queue.
- mq_timedreceive⚠
- Receive a message from a message queue
- mq_timedsend⚠
- Send message to a message queue.
- mq_unlink⚠
- Remove a message queue.
- mremap⚠
- Remap a virtual memory address
- mseal⚠
- Seals the VM’s metadata from selected syscalls.
- msgctl⚠
- System V message control operations.
- msgget⚠
- Get a System V message queue identifier.
- msgrcv⚠
- Receive messages from a System V message queue.
- msgsnd⚠
- Append the message to a System V message queue.
- msync⚠
- Synchronize a file with memory map.
- munlock⚠
- Unlock memory.
- munlockall⚠
- Unlock memory.
- munmap⚠
- Unmap files or devices from memory.
- name_to_handle_at⚠
- Obtain handle for a filename
- nanosleep⚠
- High resolution sleep.
- newfstatat⚠
- Get file status.
- open⚠
- Open and possibly create a file.
- open_by_handle_at⚠
- Obtain handle for an open file
- open_tree⚠
- openat⚠
- Open and possibly create a file within a directory.
- openat2⚠
- Open and possibly create a file (extended)
- pause⚠
- Pause the calling process to sleep until a signal is delivered.
- perf_event_open⚠
- Set up performance monitoring.
- personality⚠
- Set the process execution domain.
- pidfd_getfd⚠
- Obtain a duplicate of another process’s file descriptor.
- pidfd_open⚠
- Obtain a file descriptor that refers to a process.
- pidfd_send_signal⚠
- Signal a process through a pidfd.
- pipe⚠
- Create a pipe.
- pipe2⚠
- Create a pipe.
- pivot_root⚠
- Change the root filesystem.
- pkey_alloc⚠
- Create a new protection key.
- pkey_free⚠
- Free a protection key.
- pkey_mprotect⚠
- Set protection on a region of memory.
- poll⚠
- Wait for some event on file descriptors.
- ppoll⚠
- Wait for some event on a file descriptor.
- prctl⚠
- Operations on a process.
- pread64⚠
- Read from a file descriptor without changing file offset.
- preadv⚠
- Read from a file descriptor without changing file offset.
- preadv2⚠
- Read from a file descriptor without changing file offset.
- prlimit64⚠
- Get/set the resource limits of an arbitary process.
- process_vm_readv⚠
- Transfer data between process address spaces
- process_vm_writev⚠
- Transfer data between process address spaces
- pselect6⚠
- Sychronous I/O multiplexing.
- ptrace⚠
- Process trace.
- pwrite64⚠
- Write to a file descriptor without changing file offset.
- pwritev⚠
- Write to a file descriptor without changing file offset.
- pwritev2⚠
- Write to a file descriptor without changing file offset.
- quotactl⚠
- Manipulate disk quotes.
- quotactl_fd⚠
- Manipulate disk quotes.
- read⚠
- Read from a file descriptor.
- readahead⚠
- Initialize file head into page cache.
- readlink⚠
- Read value of a symbolic link.
- readlinkat⚠
- Read value of a symbolic link.
- readv⚠
- Read from a file descriptor into multiple buffers.
- reboot⚠
- Reboot or enable/disable Ctrl-Alt-Del.
- recvfrom⚠
- Receive a message from a socket.
- recvmmsg⚠
- Receives multile messages on a socket
- recvmsg⚠
- Receive a msg from a socket.
- remap_file_pages⚠
- Create a nonlinear file mapping.
- removexattr⚠
- Remove an extended attribute.
- rename⚠
- Change name or location of a file.
- renameat⚠
- Change name or location of a file.
- renameat2⚠
- Change name or location of a file.
- request_key⚠
- Request a key from kernel’s key management facility.
- restart_syscall⚠
- Restart a system call after interruption by a stop signal.
- rmdir⚠
- Delete a directory.
- rseq⚠
- Setup restartable sequences for caller thread.
- rt_sigaction⚠
- Examine and change a signal action.
- rt_sigpending⚠
- Examine pending signals.
- rt_sigprocmask⚠
- Change the list of currently blocked signals.
- rt_sigqueueinfo⚠
- Queue a signal and data.
- rt_sigreturn⚠
- Return from signal handler and cleanup stack frame.
- rt_sigsuspend⚠
- Wait for a signal.
- rt_sigtimedwait⚠
- Synchronously wait for queued signals.
- rt_tgsigqueueinfo⚠
- Queue a signal and data.
- sched_get_priority_max⚠
- Get static priority max value.
- sched_get_priority_min⚠
- Get static priority min value.
- sched_getaffinity⚠
- Get a thread’s CPU affinity mask.
- sched_getattr⚠
- Get scheduling policy and attributes
- sched_getparam⚠
- Get scheduling paramters.
- sched_getscheduler⚠
- Get scheduling parameter.
- sched_rr_get_interval⚠
- Get the
SCHED_RR interval for the named process. - sched_setaffinity⚠
- Set a thread’s CPU affinity mask.
- sched_setattr⚠
- Set the RT priority of a thread.
- sched_setparam⚠
- Set scheduling paramters.
- sched_setscheduler⚠
- Set scheduling parameter.
- sched_yield⚠
- Yield the processor.
- seccomp⚠
- Operate on Secure Computing state of the process.
- select⚠
- Sychronous I/O multiplexing.
- semctl⚠
- System V semaphore control operations
- semget⚠
- Get a System V semphore set identifier.
- semop⚠
- System V semphore operations.
- semtimedop⚠
- System V semaphore operations
- sendfile⚠
- Transfer data between two file descriptors.
- sendmmsg⚠
- Send multiple messages on a socket
- sendmsg⚠
- Send a message on a socket.
- sendto⚠
- Send a message on a socket.
- set_mempolicy⚠
- Set default NUMA memory policy for a thread and its children
- set_mempolicy_home_node⚠
- set_robust_list⚠
- Set the robust-futex list head of a task.
- set_thread_area⚠
- Set thread-local storage information.
- set_tid_address⚠
- Set pointer to thread ID.
- setdomainname⚠
- Set NIS domain name.
- setfsgid⚠
- Set group identify used for filesystem checkes.
- setfsuid⚠
- Set user identify used for filesystem checkes.
- setgid⚠
- Set the group ID of the calling process to
gid. - setgroups⚠
- Set list of supplementary group Ids.
- sethostname⚠
- Set hostname.
- setitimer⚠
- Set value of an interval timer.
- setns⚠
- Reassociate thread with a namespace.
- setpgid⚠
- Set the process group ID (PGID) of the process specified by
pid to pgid. - setpriority⚠
- Set program scheduling priority.
- setregid⚠
- Set real and effective group IDs of the calling process.
- setresgid⚠
- Set real, effective and saved group Ids of the calling process.
- setresuid⚠
- Set real, effective and saved user Ids of the calling process.
- setreuid⚠
- Set real and effective user IDs of the calling process.
- setrlimit⚠
- Set resource limit.
- setsid⚠
- Create a new session if the calling process is not a process group leader.
- setsockopt⚠
- Set options on sockets.
- settimeofday⚠
- Set system time and timezone.
- setuid⚠
- Set user ID of the calling process to
uid. - setxattr⚠
- Set extended attribute value.
- shmat⚠
- Attach the System V shared memory segment.
- shmctl⚠
- System V shared memory control.
- shmdt⚠
- Detach the System V shared memory segment.
- shmget⚠
- Allocates a System V shared memory segment.
- shutdown⚠
- Shutdown part of a full-duplex connection.
- sigaltstack⚠
- Get/set signal stack context.
- signalfd⚠
- Create a file descriptor to accept signals.
- signalfd4⚠
- Create a file descriptor to accept signals.
- socket⚠
- Create an endpoint for communication.
- socketpair⚠
- Create a pair of connected socket.
- splice⚠
- Splice data to/from pipe.
- stat⚠
- Get file status about a file.
- statfs⚠
- Get filesystem statistics.
- statmount⚠
- statx⚠
- Get file status about a file (extended).
- swapoff⚠
- Stop swapping to file/device.
- swapon⚠
- Start swapping to file/device.
- symlink⚠
- Make a new name for a file.
- symlinkat⚠
- Make a new name for a file.
- sync⚠
- Commit filesystem caches to disk.
- sync_file_range⚠
- Sync a file segment to disk
- syncfs⚠
- Commit filesystem cache related to
fd to disk. - sysfs⚠
- Get filesystem type information.
- sysinfo⚠
- Return system information.
- syslog⚠
- Read and/or clear kernel message ring buffer.
- tee⚠
- Duplicate pipe content.
- tgkill⚠
- Send a signal to a thread.
- time⚠
- Get time in seconds.
- timer_create⚠
- Create a per-process timer
- timer_delete⚠
- Delete a per-process timer
- timer_getoverrun⚠
- Get overrun count for a per-process timer.
- timer_gettime⚠
- Fetch state of per-process timer>
- timer_settime⚠
- Arm/disarm state of per-process timer.
- timerfd_create⚠
- Create a timer that notifies via a file descriptor.
- timerfd_gettime⚠
- Get current timer via a file descriptor.
- timerfd_settime⚠
- Set current timer via a file descriptor.
- times⚠
- Get process times.
- tkill⚠
- Send a signal to a thread (obsolete).
- truncate⚠
- Truncate a file to a specified length.
- umask⚠
- Set file mode creation mask.
- umount2⚠
- Unmount filesystem.
- uname⚠
- Get name and information about current kernel.
- unlink⚠
- Delete a name and possibly the file it refers to.
- unlinkat⚠
- Delete a name and possibly the file it refers to.
- unshare⚠
- Disassociate parts of the process execution context
- uselib⚠
- Load shared library.
- userfaultfd⚠
- Create a file descriptor to handle page faults in user space.
- ustat⚠
- Get filesystem statistics
- utime⚠
- Change file last access and modification time.
- utimensat⚠
- Change time timestamps with nanosecond precision.
- utimes⚠
- Change file last access and modification time.
- vfork⚠
- Create a child process and wait until it is terminated.
- vhangup⚠
- Virtually hang up the current terminal.
- vmsplice⚠
- Splice user page into a pipe.
- wait4⚠
- Wait for process to change state.
- waitid⚠
- Wait for process to change state.
- write⚠
- Write to a file descriptor.
- writev⚠
- Write to a file descriptor from multiple buffers.