#[repr(C)]pub struct pollfd_t {
pub fd: i32,
pub events: i16,
pub revents: i16,
}Fields
fd: i32File descriptor
events: i16Requested events.
Used as input parameter, a bit mask specifying the events the application is interested in for the file descriptor fd.
revents: i16Returned events
Used an output parameter, filled by the kernel with the events that actually occurred.